SCF Functions
=============

To use the Huzinaga projector with Projection-based embedding,
it's necessary to make some changes to Hartree-Fock and Kohn-Sham SCF functions.

Huzinaga SCF Methods
--------------------

.. automodule:: nbed.scf.huzinaga_scf
   :members:
   :undoc-members:
   :show-inheritance:

Embedded hcore Functions
------------------------

.. automodule:: nbed.scf.embedded_hcore_funcs
   :members:
   :undoc-members:
   :show-inheritance:
